(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    143054,       3146]
NotebookOptionsPosition[    139486,       3023]
NotebookOutlinePosition[    139822,       3038]
CellTagsIndexPosition[    139779,       3035]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "In this notebook we will examine the Eyring equation.Specifically, how to \
fit data to the Eyring equation properly. The Eyring equation is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", 
    RowBox[{
     FractionBox[
      SubscriptBox["k", "b"], "h"], "T", " ", 
     SuperscriptBox["e", 
      FractionBox[
       RowBox[{"-", "\[CapitalDelta]G"}], 
       RowBox[{"R", " ", "T"}]]]}]}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]G", " ", "=", " ", 
    RowBox[{"\[CapitalDelta]H", " ", "-", " ", 
     RowBox[{"T", " ", "\[CapitalDelta]S"}]}]}], TraditionalForm]]],
 ".\n\nLet' s take a look at a system with theoretical parameters \
\[CapitalDelta]H = 75 kJ/mol and \[CapitalDelta]S = -15\nJ/(mol K).We' ll do \
a couple simulated \"experiments\" (with error) and see how different fitting \
strategies work.While looking at this, remember that a good fitting strategy \
will produce fitting parameters close to the theoretical values."
}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517236409214451*^9, 3.517236563379677*^9}, {
  3.517238182900346*^9, 3.517238200843443*^9}},
 EmphasizeSyntaxErrors->True,
 FormatType->"TextForm"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<PhysicalConstants`\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.517148331555438*^9, 3.517148338181961*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"h", "=", 
   RowBox[{
    RowBox[{"N", "[", "PlanckConstant", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kb", "=", 
   RowBox[{
    RowBox[{"N", "[", "BoltzmannConstant", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{
    RowBox[{"N", "[", "MolarGasConstant", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.517148345203554*^9, 3.5171483747576*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"theo\[CapitalDelta]H", "=", 
   RowBox[{"75", "*", 
    RowBox[{"10", "^", "3"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"theo\[CapitalDelta]S", "=", 
   RowBox[{"-", "15"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"theoParams", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[CapitalDelta]H", "\[Rule]", "theo\[CapitalDelta]H"}], ",", 
     RowBox[{"\[CapitalDelta]S", "\[Rule]", "theo\[CapitalDelta]S"}]}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.517148381704626*^9, 3.517148406647957*^9}, {
  3.517149104136154*^9, 3.517149126137754*^9}, {3.51714934854526*^9, 
  3.517149348562814*^9}, {3.517149466626249*^9, 3.517149467344094*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"model", "=", 
   RowBox[{
    FractionBox["kb", "h"], "T", "*", 
    RowBox[{"Exp", "[", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[CapitalDelta]H", "-", 
        RowBox[{"T", " ", "\[CapitalDelta]S"}]}], 
       RowBox[{"R", " ", "T"}]]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"modelParams", "=", 
   RowBox[{"{", 
    RowBox[{"\[CapitalDelta]H", ",", "\[CapitalDelta]S"}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.517148764471626*^9, 3.517148844116752*^9}, {
  3.517149417630211*^9, 3.517149425757173*^9}}],

Cell["\<\
This is what the theoretical plot should look like. The log plot will \
actually be more informative, so we' ll stick with that.\
\>", "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517238235156452*^9, 3.517238265565969*^9}},
 FormatType->"TextForm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theoPlot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"model", "/.", "theoParams"}], ",", 
    RowBox[{"{", 
     RowBox[{"T", ",", "200", ",", "300"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517149092304651*^9, 3.517149092769981*^9}, {
  3.517149129163559*^9, 3.517149139315566*^9}, {3.517149238720715*^9, 
  3.517149240619979*^9}, {3.517149282055808*^9, 3.517149284725527*^9}, {
  3.517149348574096*^9, 3.517149348582481*^9}, {3.517149470723918*^9, 
  3.517149471392791*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4Vs8XAHBbUfYlJEkifYuUyFYzpywpIbtkCVnefVFCluwqSpGEKESS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{200., 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.517149139782425*^9, 3.517149240943095*^9, 3.517149285026698*^9, 
   3.517149374289426*^9, 3.517149471871243*^9, 3.517234435688193*^9, 
   3.51723492083507*^9, 3.517238206009775*^9, {3.51723929567471*^9, 
   3.517239318830399*^9}, 3.51724754016841*^9, {3.517249396714433*^9, 
   3.517249424172609*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theoLogPlot", "=", 
  RowBox[{"LogPlot", "[", 
   RowBox[{
    RowBox[{"model", "/.", "theoParams"}], ",", 
    RowBox[{"{", 
     RowBox[{"T", ",", "200", ",", "300"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517149143460562*^9, 3.51714915219372*^9}, {
  3.51714923059234*^9, 3.517149233965768*^9}, {3.517149348642401*^9, 
  3.517149348650436*^9}, {3.517149473999052*^9, 3.517149474684773*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzX9YywkcB/DVdzWP8mx1k+wpW7WWstTwJMfN5/xcSCrnSObRo1tb+/nl
7vxY3VOSUFdk5iLTiuQUJfppPlQPmlRSrh/Ij8su1TnSpR/c7o/3835e/7zf
HjGqiFhbCoUSas3/XVS4mkqhSIHuJhqY1ilA0ae45eNWOx1WXxY+EaBlzZHk
ERspvN+UlaVqFyBv6AFlkJCCOOh8fWurAAsWREx20qQwRC/p1jcK8Ozt6JFr
dCn4V/56269WgMe7NRYJWwrUnGVh8QYB7qOfedAslIIPbd2RTT8IUHk1hGNJ
lsLm/S589UAg7uXbChPuSCG9ZPO3T7WB+NH4nNFGkYGoo3p3qlMgZke4qDQr
ZDB98FDiOWEAhjz9Xp9+QAZzztvVJCnmokfe+zXv7sqg/WSLrX+mP8q2l11j
OsRD2b+fC9lVfDSPavuuh8RDfdr9K+yPc3C9+VyBISMeuDUpLvu4c/CvPc18
+6Z42G3h1Qlj/XCY4yXzd5BDb2RoM1Hsi562LfNy18uhe1ZcR6FlNkpMhxoO
Z8hh9DDZX7RgNjZfO/XK1CqHle324+O7fbAw/+GNcqYCMr6r9guo5aFeSd/o
E6mA8Jc2eQ3OPCwii7QvTyqgtb/e0VvsjW3h61WsDgWccKTdl1RykS1bN5jD
UoIkrWLjHzQu9mhVnJ5tSlhU6P1Qu80LS2W57jlnlGBOn6rzve2JF49xL5zr
VQJ19GSLmuWJFdk3Rr04KvD9U/3ThiQPXJiloMSJVWBkWVoODHKwsyEhezhP
BdqgrLbrYRzM7jj1brJXBUlHZWuPJrAxOCt1oNBZDcax19pw0SwUz4tcLFig
hi0fAsoN7u7IWOb9955INdzNecsLcXDDyKF8y84f1fAsJiY7vI+FnlNmr6br
1JD2z6NxSudM9DMIKaxy615D7LLmx65Y98jmy712NbjvNE9cMM1Ay67GmKCP
amDVDxWPmFzwbOlSR9EMDdyp6+I8L56OvdHVLNeFGhBXtwUbypgYdfDuAdEm
DQS5BnFMt77C2DVJ89z3aGB+MlYyap1xQgurruo1sD/67T5+kxNy1102vKnS
QKxFNz7ZxMCUU5cif+nWQE1pn4uwhI7qiBJ5+5gGVg4srqBbpuHgRbG52Y0E
dmP9QrmtI47ImZlpS0jgJo+RG5ZPxeCS6OK8rST43Z8RV3d8CjqkhzttTyDh
QkNmh7nOHmVP1nZ1nSGhFVd9Oj3TDm+6dikluSTsf7EqY5GzHTKi4ohhq11y
qZlPptrhjZ4U/jQDCRErj3czJ6ho+/Jm4tI8EqIXWfQnnlExZyDAq+A8Ca8k
TrqL+VQ02zDlihISnr/yFXvOpeKs5UbKmNUi0Tf6Jh4VyZRAXeoVEuaqupfs
ZVPRlRZqMlwl4cXwsaZWBhV3OqYyHpWR4H/lKZH2gcAJl9HyoAoSLDbGmilV
BIZtTg2ps3rAZqiyupRA42/MZ2GVJLjb+3sqLhEochPQpFUkJESIg9tOE3jC
Q7bldI31v+YgWZBI4JuY0UGfWhIadTsebvmZwK8LUpPLrT775bWOriawl5f/
e9NNEmg9tRLtDgLnxwkgykSCPvGzZn4UgalFtx73WZ3OuPOmP4LAzv5Q6a5b
JFzif75nXEsgn98z+cXqBmXR9K0rCPwPd9pNcw==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{200, -17.847868697743305`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-15.935774094164366`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.285186528023216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.894320219336205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.614018254182046`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.395329053217216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.215988124561399`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.063971917262773`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.932044374220226`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.330603908176274`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.680016342035124`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.289150033348113`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.008848068193954`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.790158867229126, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.610817938573309, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.458801731274683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.326874188232134, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.725433722188183, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.074846156047033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.683979847360021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.403677882205863, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.184988681241033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.005647752585217, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.853631545286591, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.721704002244043, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-18.420680743952367`, 
       FormBox["\"\"", TraditionalForm]}, {-13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-15.935774094164366`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.285186528023216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.894320219336205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.614018254182046`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.395329053217216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.215988124561399`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.063971917262773`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.932044374220226`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.330603908176274`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.680016342035124`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.289150033348113`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.008848068193954`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.790158867229126, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.610817938573309, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.458801731274683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.326874188232134, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.725433722188183, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.074846156047033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.683979847360021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.403677882205863, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.184988681241033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.005647752585217, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.853631545286591, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.721704002244043, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{200, 300}, {-17.847868697743305`, -2.408376855118919}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{-18.420680743952367`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-15.935774094164366`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-15.285186528023216`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.894320219336205`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.614018254182046`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.395329053217216`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.215988124561399`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.063971917262773`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-13.932044374220226`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.330603908176274`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.680016342035124`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.289150033348113`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.008848068193954`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.790158867229126, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.610817938573309, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.458801731274683, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.326874188232134, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.725433722188183, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.074846156047033, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.683979847360021, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.403677882205863, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.184988681241033, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.005647752585217, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.853631545286591, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.721704002244043, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.517149152638986*^9, 3.5171492345641*^9, 3.51714937448101*^9, 
   3.517149475027223*^9, 3.517234435933478*^9, 3.517234921072188*^9, 
   3.517238206227808*^9, {3.517239295901338*^9, 3.517239319055767*^9}, 
   3.517247540378793*^9, {3.517249396917619*^9, 3.517249424471392*^9}}]
}, Open  ]],

Cell["\<\
This is how we' ll run our experiment. Each data point will be randomly \
distributed within 20 % of the exact theoretical value.\
\>", "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517238315820066*^9, 3.51723835462726*^9}},
 FormatType->"TextForm"],

Cell[BoxData[
 RowBox[{
  RowBox[{"uniformRelativeError", "[", "x_", "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"T", ",", "err", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"T", "=", 
      RowBox[{"Range", "[", 
       RowBox[{"200", ",", "300", ",", "10"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"k", "=", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "-", "x"}], ",", 
            RowBox[{"1", "+", "x"}]}], "}"}], "]"}], "*", 
         FractionBox["kb", "h"], "*", "t", "*", 
         RowBox[{"Exp", "[", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"theo\[CapitalDelta]H", "-", 
             RowBox[{"t", "*", "theo\[CapitalDelta]S"}]}], 
            RowBox[{"R", "*", "t"}]]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "T"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"T", ",", "k"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517148641031974*^9, 3.517148730266161*^9}, {
   3.517148863074779*^9, 3.517149004775694*^9}, {3.517149348662558*^9, 
   3.517149348672305*^9}, 3.517238295785844*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"exp1T", ",", "exp1k"}], "}"}], "=", 
   RowBox[{"uniformRelativeError", "[", "0.2", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.517149008667572*^9, 3.517149042408021*^9}, {
  3.517247455777114*^9, 3.517247492082043*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"exp1", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"exp1T", ",", "exp1k"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "exp1", "]"}]}], "Input",
 CellChangeTimes->{{3.517247480798701*^9, 3.517247520303983*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"200", "2.094938217307259`*^-8"},
     {"210", "1.4981695118630194`*^-7"},
     {"220", "1.318980055325833`*^-6"},
     {"230", "7.1938999272159054`*^-6"},
     {"240", "0.00003763973542048922`"},
     {"250", "0.00017510023159892122`"},
     {"260", "0.000820416557221391`"},
     {"270", "0.0030993719514421435`"},
     {"280", "0.009365869553789543`"},
     {"290", "0.030490887720361768`"},
     {"300", "0.07442238543814138`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.517247493895733*^9, 3.517247540441863*^9}, {
  3.517249397248423*^9, 3.517249424760928*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp1ListLogPlot", "=", 
  RowBox[{"ListLogPlot", "[", 
   RowBox[{"exp1", ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "Medium"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517149072643585*^9, 3.517149081535605*^9}, {
  3.517149221100237*^9, 3.517149224467751*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQGZDj/3HfNIWGd4AMx1yHJ4pJ3ztTZXH8JvyHaY
5JCgfUpYG8I/kOOwUq3sk916dQifIc9h/8Ps6p/xKlD9+Q5JfR92PPBRhPIL
HHZEGxvY5MhA+A8KHIRPtRQYSotDzS90WBK1puf4OiEIX6HI4Y4m9zGDN9xQ
+4ocTOvTCjafYDkw1NwLAPoNcGI=
   "], {
    {Hue[0.67, 0.6, 0.6], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 12], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 13], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 14], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 15], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 16], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 17], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 18], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 19], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 20], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 21], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 22]}, {}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{200., -17.68115668155858},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-15.935774094164366`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.285186528023216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.894320219336205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.614018254182046`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.395329053217216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.215988124561399`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.063971917262773`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.932044374220226`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.330603908176274`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.680016342035124`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.289150033348113`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.008848068193954`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.790158867229126, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.610817938573309, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.458801731274683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.326874188232134, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.725433722188183, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.074846156047033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.683979847360021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.403677882205863, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.184988681241033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.005647752585217, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.853631545286591, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.721704002244043, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-18.420680743952367`, 
       FormBox["\"\"", TraditionalForm]}, {-13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-15.935774094164366`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.285186528023216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.894320219336205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.614018254182046`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.395329053217216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.215988124561399`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.063971917262773`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.932044374220226`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.330603908176274`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.680016342035124`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.289150033348113`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.008848068193954`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.790158867229126, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.610817938573309, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.458801731274683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.326874188232134, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.725433722188183, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.074846156047033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.683979847360021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.403677882205863, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.184988681241033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.005647752585217, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.853631545286591, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.721704002244043, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{200., 300.}, {-17.68115668155858, -2.5979985028533528`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{-18.420680743952367`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-15.935774094164366`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-15.285186528023216`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.894320219336205`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.614018254182046`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.395329053217216`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.215988124561399`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.063971917262773`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-13.932044374220226`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.330603908176274`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.680016342035124`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.289150033348113`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.008848068193954`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.790158867229126, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.610817938573309, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.458801731274683, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.326874188232134, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.725433722188183, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.074846156047033, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.683979847360021, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.403677882205863, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.184988681241033, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.005647752585217, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.853631545286591, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.721704002244043, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.517149081887936*^9, 3.517149224975675*^9, 3.517149374920747*^9, 
   3.517149564391257*^9, 3.517234436708674*^9, 3.517234921712084*^9, 
   3.517238206632058*^9, {3.517239296297378*^9, 3.517239319426664*^9}, {
   3.517247504271351*^9, 3.517247540779013*^9}, {3.517249397459535*^9, 
   3.517249425060114*^9}}]
}, Open  ]],

Cell["\<\
All right, we' ve got our data. Let' s start fitting. Mathematica has a non - \
linear fitting routine built - in, called FindFit.\
\>", "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517238384064322*^9, 3.517238439528248*^9}},
 FormatType->"TextForm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp1Params", "=", 
  RowBox[{"FindFit", "[", 
   RowBox[{"exp1", ",", "model", ",", "modelParams", ",", "T", ",", 
    RowBox[{"Method", "\[Rule]", "Gradient"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517149339123265*^9, 3.517149342200091*^9}, {
  3.517149380831297*^9, 3.517149412030696*^9}, {3.51723540647629*^9, 
  3.517235409151099*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CapitalDelta]H", "\[Rule]", "65485.38988786002`"}], ",", 
   RowBox[{"\[CapitalDelta]S", "\[Rule]", 
    RowBox[{"-", "48.260576830184924`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.517149374984052*^9, 3.517149430623473*^9, 3.517149565809852*^9, 
   3.517234436906185*^9, 3.517234921981959*^9, 3.517235409352002*^9, 
   3.51723820688485*^9, {3.517239296460296*^9, 3.517239319473027*^9}, {
   3.517247526661704*^9, 3.517247540898204*^9}, {3.517249397505505*^9, 
   3.51724942540121*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp1LogPlot", "=", 
  RowBox[{"LogPlot", "[", 
   RowBox[{
    RowBox[{"model", "/.", "exp1Params"}], ",", 
    RowBox[{"{", 
     RowBox[{"T", ",", "200", ",", "300"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517149440857603*^9, 3.517149457894019*^9}, {
  3.517149496909163*^9, 3.517149505225598*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVz2s01AkYBvChGRQyNGlMhrkIa0fovtXyplp0YZl2tkXqtDrNzVz+UrTU
uo20aiu3IZcw0rCJIVKLt4vqhOwqbaSatGUK0R6sbXPa2Q/Pec7v03Me9l55
2D5TEom03Zj/W1sVQCaRRNCvljTvYXlj4D/Cjf8aXcKdnLrn5I2GLcdTpk1E
UHh/gr+S6Y2u77pIY3NEsP72atk8hjdqVoTN9puLoJqTu7hpgTeWXI+cbrAR
wS6tQLDA3BvPPFEa9juLgJvdHH3viRcetinq6vEVwdprc2I7D3mhrC6IZUgR
gWI8a7lv+VJM4Jn6Jt0QwVm2+Jvbzzxxqvw59QFJDHFZH7Ze4Xhidpi9XLlJ
DH0SwbqScB4GPf02PytVDD2vHlZKKj5HdtlfWybuiOEF1+OWRu+B4t26Bpql
BHzLtRbMJR7YOZP4+nKQBPRSWVN0wmcY3HlOU3pCAomcyqi8G+74Jr6HZ9Yt
Aavr/l0Wi91xksUVe1pKIY18VlqU4IYc09+WFQdLwTI5b/7Jblfc35bRkXlC
CvByfKjPyxV7GtQv236XgoMlVf0sYwlWVdxvaqTFQMFV5qqxVy6YL7PZ4caP
AeY7asPBUBfUEtrEobwYsG2IG/Fo4OKD0GA541EMaHYco79lc9FZvG2skCED
5xcZfrwMDg4mylmDu2Tw5tLCp4Pv2VgvLmYWFskgwLXi+WMhGy+cdjl/Ti8D
i0th402PWNic3TTDZckhtO6W6sjXLFx9KoYkjJJDrGBoRF/sjP0dSdmTZXKg
Hv5y85pMJ8x+pJ6Y1csh+YzFF44/MXHNKdVolZ0CCgtXXjdPdMSoZfx1PisU
0OIaksM7uBip/kvG4/kKGE7gt2vTGch/V2GIjlNAXuXI6540B+RYuAfY5CpA
Yb2ipU5NR49SXxKjUQE3KuSGk42L8Gavyae7fQqwrrcLqkF7NMTe27tqSgF2
tzasT9AvxJJ6P6vARUqoDjrQZfqehvrIqwz6aiXc3ulRW0+jYXj6ndRAgRIC
fE0mLvstwH1bkpcx45WwXL1IOhthhx8T4au6fCXwI9xzko7bosu2X0qHW5SQ
rnbr1FVTMU1dzT/6RAkRIw8892hsUBFWK+37oIS4AzU1c+3n49iFqM4eRwLk
/nb9dKkVTktpPx9bT8Cfm3s4Ey/n4ZrayItlEQQk5Os2ZQrnomVWqO3uJALO
H48/pOw1R/EfWwcGigggmZPaCyLNsJU+INtfTMA6KesHZ4EZUsOFcyaNFoRs
y68MMcOmwTSedSkBPnc14zp/MzQdaj3iV0bAaJDUudfdDAtHvbiaSgLCpqdj
OVMU7DShSWNqCfCyXds07yQFnTaWkz4Ybdj34/dFGRQk0rxzVZcIaNV3yJcm
U5Buvr2ttI6Alk+8Sv4BCkZbqai9OgLS6akp5eEU/Gg/07iqmYCJXEtSmBsF
Q3aqgm4aPXptd8EbFgXLC2jPQq4Y//OXnk5mUDDQ0cdc1EJAx32HIp01BXPY
4u/OXjPuP/Z3cpgk4/DemTG3XwnQKVKrG8bIuFajSmk0OjjpY07wMBn1rhU1
3a0E0OceSksfIONyoQ+EtxFwlCbMZD8ko0rb/vC10ZEXFaOt3WTsf7tdFNtO
wIaiYxfD75CRxxuc/WT0+eqqrr+RjP8BhR5CGg==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{200, -16.126475776451887`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {-15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.01948336229021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.73180128983843, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.326336181730264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.172185501903007`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.038654109278484`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.9208710736221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {-13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {-11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {-15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.01948336229021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.73180128983843, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.326336181730264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.172185501903007`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.038654109278484`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.9208710736221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{200, 300}, {-16.126475776451887`, -2.5942226399104866`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{-16.11809565095832, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {-15.424948470398375`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-15.01948336229021, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.73180128983843, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.508657738524219`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.326336181730264`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.172185501903007`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.038654109278484`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-13.9208710736221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.716898269296165`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.429216196844383`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.02375108873622, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.86960040890896, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.736069016284437`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.618285980628055`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.517149499888017*^9, 3.517149505584884*^9}, 
   3.517149569667306*^9, 3.517234437297645*^9, 3.517234922318017*^9, 
   3.517238207062737*^9, {3.517239296665844*^9, 3.517239319710086*^9}, 
   3.517247541250493*^9, {3.517249397677228*^9, 3.51724942569019*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"exp1LogPlot", ",", "exp1ListLogPlot"}], "]"}]], "Input",
 CellChangeTimes->{{3.517149511782345*^9, 3.517149525892747*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVz2s01AkYBvChGRQyNGlMhrkIa0fovtXyplp0YZl2tkXqtDrNzVz+UrTU
uo20aiu3IZcw0rCJIVKLt4vqhOwqbaSatGUK0R6sbXPa2Q/Pec7v03Me9l55
2D5TEom03Zj/W1sVQCaRRNCvljTvYXlj4D/Cjf8aXcKdnLrn5I2GLcdTpk1E
UHh/gr+S6Y2u77pIY3NEsP72atk8hjdqVoTN9puLoJqTu7hpgTeWXI+cbrAR
wS6tQLDA3BvPPFEa9juLgJvdHH3viRcetinq6vEVwdprc2I7D3mhrC6IZUgR
gWI8a7lv+VJM4Jn6Jt0QwVm2+Jvbzzxxqvw59QFJDHFZH7Ze4Xhidpi9XLlJ
DH0SwbqScB4GPf02PytVDD2vHlZKKj5HdtlfWybuiOEF1+OWRu+B4t26Bpql
BHzLtRbMJR7YOZP4+nKQBPRSWVN0wmcY3HlOU3pCAomcyqi8G+74Jr6HZ9Yt
Aavr/l0Wi91xksUVe1pKIY18VlqU4IYc09+WFQdLwTI5b/7Jblfc35bRkXlC
CvByfKjPyxV7GtQv236XgoMlVf0sYwlWVdxvaqTFQMFV5qqxVy6YL7PZ4caP
AeY7asPBUBfUEtrEobwYsG2IG/Fo4OKD0GA541EMaHYco79lc9FZvG2skCED
5xcZfrwMDg4mylmDu2Tw5tLCp4Pv2VgvLmYWFskgwLXi+WMhGy+cdjl/Ti8D
i0th402PWNic3TTDZckhtO6W6sjXLFx9KoYkjJJDrGBoRF/sjP0dSdmTZXKg
Hv5y85pMJ8x+pJ6Y1csh+YzFF44/MXHNKdVolZ0CCgtXXjdPdMSoZfx1PisU
0OIaksM7uBip/kvG4/kKGE7gt2vTGch/V2GIjlNAXuXI6540B+RYuAfY5CpA
Yb2ipU5NR49SXxKjUQE3KuSGk42L8Gavyae7fQqwrrcLqkF7NMTe27tqSgF2
tzasT9AvxJJ6P6vARUqoDjrQZfqehvrIqwz6aiXc3ulRW0+jYXj6ndRAgRIC
fE0mLvstwH1bkpcx45WwXL1IOhthhx8T4au6fCXwI9xzko7bosu2X0qHW5SQ
rnbr1FVTMU1dzT/6RAkRIw8892hsUBFWK+37oIS4AzU1c+3n49iFqM4eRwLk
/nb9dKkVTktpPx9bT8Cfm3s4Ey/n4ZrayItlEQQk5Os2ZQrnomVWqO3uJALO
H48/pOw1R/EfWwcGigggmZPaCyLNsJU+INtfTMA6KesHZ4EZUsOFcyaNFoRs
y68MMcOmwTSedSkBPnc14zp/MzQdaj3iV0bAaJDUudfdDAtHvbiaSgLCpqdj
OVMU7DShSWNqCfCyXds07yQFnTaWkz4Ybdj34/dFGRQk0rxzVZcIaNV3yJcm
U5Buvr2ttI6Alk+8Sv4BCkZbqai9OgLS6akp5eEU/Gg/07iqmYCJXEtSmBsF
Q3aqgm4aPXptd8EbFgXLC2jPQq4Y//OXnk5mUDDQ0cdc1EJAx32HIp01BXPY
4u/OXjPuP/Z3cpgk4/DemTG3XwnQKVKrG8bIuFajSmk0OjjpY07wMBn1rhU1
3a0E0OceSksfIONyoQ+EtxFwlCbMZD8ko0rb/vC10ZEXFaOt3WTsf7tdFNtO
wIaiYxfD75CRxxuc/WT0+eqqrr+RjP8BhR5CGg==
      "]]}}, 
   GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQGZDj/3HfNIWGd4AMx1yHJ4pJ3ztTZXH8JvyHaY
5JCgfUpYG8I/kOOwUq3sk916dQifIc9h/8Ps6p/xKlD9+Q5JfR92PPBRhPIL
HHZEGxvY5MhA+A8KHIRPtRQYSotDzS90WBK1puf4OiEIX6HI4Y4m9zGDN9xQ
+4ocTOvTCjafYDkw1NwLAPoNcGI=
    "], {
     {Hue[0.67, 0.6, 0.6], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 12], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 13], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 14], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 15], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 16], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 17], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 18], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 19], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 20], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 21], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 22]}, {}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{200, -16.126475776451887`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {-15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.01948336229021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.73180128983843, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.326336181730264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.172185501903007`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.038654109278484`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.9208710736221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {-13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {-11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {-15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.01948336229021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.73180128983843, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.326336181730264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.172185501903007`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.038654109278484`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.9208710736221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{200, 300}, {-16.126475776451887`, -2.5942226399104866`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{-16.11809565095832, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {-15.424948470398375`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-15.01948336229021, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.73180128983843, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.508657738524219`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.326336181730264`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.172185501903007`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.038654109278484`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-13.9208710736221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.716898269296165`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.429216196844383`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.02375108873622, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.86960040890896, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.736069016284437`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.618285980628055`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.517149526408411*^9, 3.517149571486606*^9, 3.517234437503006*^9, 
   3.517234922630071*^9, 3.517238207249395*^9, {3.517239297035115*^9, 
   3.517239320015172*^9}, 3.517247541568807*^9, {3.517249397820486*^9, 
   3.517249426017268*^9}}]
}, Open  ]],

Cell["\<\
As we can see, the fit isn' t great. The parameters we got are not very cloes \
to the theoretical values. However, Mathematica' s curve-fitting is not to \
blame. It is actually our whole curve-fitting strategy that is at fault. To \
see why, let's take a look at how we're currently approaching curve-fitting.

Curve-fitting is the process of getting \"the best fit\" to the data. In \
general, \"the best fit\" to a set of data is defined as the fit which \
minimizes the squared error. Let's take a look at the residuals of our fit to \
get a better idea of what that means.\
\>", "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517238567934172*^9, 3.517238786975417*^9}},
 FormatType->"TextForm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp1Residuals", "=", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"model", "/.", "exp1Params"}], ",", 
     RowBox[{"{", 
      RowBox[{"T", ",", "200", ",", "300", ",", "10"}], "}"}]}], "]"}], "-", 
   RowBox[{"exp1", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.51714962260896*^9, 3.517149626909136*^9}, {
  3.517149658510065*^9, 3.51714966592696*^9}, {3.517151530408056*^9, 
  3.517151556788094*^9}, {3.51723444986703*^9, 3.517234594235318*^9}, {
  3.5172346598113*^9, 3.517234758592757*^9}, {3.517235689370897*^9, 
  3.517235695478376*^9}, {3.517235803472778*^9, 3.517235808690482*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "7.821606595421067`*^-8", ",", "5.29328508258283`*^-7", ",", 
   "2.594307434135401`*^-6", ",", "0.000012207898692774678`", ",", 
   "0.00004669132424434431`", ",", "0.000151341378311404`", ",", 
   "0.00032003022053752467`", ",", "0.0005374425798305906`", ",", 
   "0.0013238707888781447`", ",", 
   RowBox[{"-", "0.0012860168645753844`"}], ",", "0.0002815537708723004`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5172347355926*^9, 3.517234759705231*^9}, 
   3.517234922919116*^9, 3.517235695970829*^9, {3.517235806583646*^9, 
   3.517235809040394*^9}, 3.517238207308152*^9, {3.517239297090517*^9, 
   3.517239320148467*^9}, 3.517247541686508*^9, {3.517249397857778*^9, 
   3.517249426350186*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp1ResidualPlot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"exp1Residuals", ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "Medium"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517234770210437*^9, 3.517234811267889*^9}, {
  3.517234893630942*^9, 3.517234893917011*^9}, {3.517235610949038*^9, 
  3.51723561126977*^9}, {3.517235703023247*^9, 3.517235709883396*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7BOja6Z+/1diBxVwYOgT3Pz00EIon8PhjYPv
DOvDR6F8AYeaZvZLArNeQvkiDmcUk9afreKwh/AlHOzk87t0rilD+TIODY07
Qsx/mkD5Cg4bJjxRS53jCOUrORjcbMrfviEUyldxaChnl/gkGLofwldzYBB5
bbOh2Mh+qLkXAC8+Wmw=
   "], {
    {Hue[0.67, 0.6, 0.6], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 12], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 13], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 14], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 15], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 16], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 17], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 18], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 19], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 20], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 21], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 22]}, {}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 11.}, {-0.0012860168645753844`, 0.0013238707888781447`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.517234795275899*^9, 3.517234811521558*^9}, {
   3.517234894317996*^9, 3.517234923299204*^9}, 3.517235611677292*^9, {
   3.517235698883062*^9, 3.517235710241038*^9}, 3.517235813228134*^9, 
   3.517238207433989*^9, {3.517239297233459*^9, 3.517239320260551*^9}, 
   3.517247541854551*^9, {3.517249397989242*^9, 3.51724942651345*^9}}]
}, Open  ]],

Cell[TextData[{
 "Here we can that the errors are, in general, very small (none of them are \
larger than 0.001 or so). The \"squared error\" that we mentioned previously \
is just the sum of the squares of the residuals (i.e., ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["\[CapitalSigma]r", "i"], "2"], TraditionalForm]]],
 "). Mathematica picked out \[CapitalDelta]H and \[CapitalDelta]S such that \
the squared error was as small as possible.\n\nThat is not what we want.\n\n\
Our experiment had ",
 StyleBox["relative",
  FontSlant->"Italic"],
 " error. That is, each data point was within 20% of the correct value. Let's \
take a look at the ",
 StyleBox["relative",
  FontSlant->"Italic"],
 " error of the fit that Mathematica gave us."
}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517238815726127*^9, 3.517238818315335*^9}, {
  3.517238878279692*^9, 3.517239113170474*^9}, {3.517239157437078*^9, 
  3.517239241889764*^9}, {3.517239340781529*^9, 3.51723935948692*^9}, {
  3.517247559814151*^9, 3.517247567990075*^9}},
 EmphasizeSyntaxErrors->True,
 FormatType->"TextForm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"exp1Residuals", "/", 
    RowBox[{"exp1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "Medium"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.517235675678056*^9, 3.517235726756159*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7G/7r/oVfY/XASrgUMB38dBbZx4on8PBJnJx
X0HFf3sIX8BhodjndZfVfkP5Ig4zuVxUGW9+hvIlHNSYzNOKV7yG8mUc8lY5
/5P5fgPKV3AoX6e3VdzoGJSv5PCHwz/0mPghKF/FYUkki53NjKX7IXw1h1nr
7K+9+ptnP9TcCwAmFF98
   "], {
    {Hue[0.67, 0.6, 0.6], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 12], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 13], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 14], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 15], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 16], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 17], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 18], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 19], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 20], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 21], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 22]}, {}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 11.}, {-0.04217708832782144, 3.733573873827465}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.517235727070938*^9, 3.517235816241109*^9, 3.517238207742409*^9, {
   3.517239298114781*^9, 3.517239320325531*^9}, 3.51724754200677*^9, {
   3.517249398053653*^9, 3.517249426576278*^9}}]
}, Open  ]],

Cell[TextData[{
 "The relative error is ",
 StyleBox["terrible",
  FontSlant->"Italic"],
 ". Because Mathematica tried to minimize the ",
 StyleBox["absolute",
  FontSlant->"Italic"],
 " error, it cared much more about getting the later points close. An 80% \
error at low temperatures is barely even registered as important (but it \
obviously should be).\n\nIf we want to get a good fit for our experiment, we \
really want to minimize the squared relative error instead of the squared \
absolute error. Luckily, Mathematica has an easy way to do that. We can just \
give it a different function to try and minimize."
}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517239255024126*^9, 3.517239288184536*^9}, {
  3.517239374168261*^9, 3.517239427766203*^9}, {3.517239463430864*^9, 
  3.51723952497018*^9}, {3.517247592024329*^9, 3.51724760679939*^9}, {
  3.517248120167794*^9, 3.517248123426862*^9}},
 EmphasizeSyntaxErrors->True,
 FormatType->"TextForm"],

Cell[BoxData[
 RowBox[{
  RowBox[{"weightedNorm", "[", "residuals_", "]"}], ":=", 
  RowBox[{"Norm", "[", 
   RowBox[{"residuals", "/", "exp1k"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517235008277973*^9, 3.517235028601691*^9}, {
   3.517235157436914*^9, 3.517235164150995*^9}, 3.517248556127605*^9}],

Cell["\<\
With this new weighted function, let's try doing the fit again.\
\>", "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517239541952095*^9, 3.517239573981252*^9}},
 FormatType->"TextForm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp1WeightedParams", "=", 
  RowBox[{"FindFit", "[", 
   RowBox[{"exp1", ",", "model", ",", "modelParams", ",", "T", ",", 
    RowBox[{"NormFunction", "\[Rule]", "weightedNorm"}], ",", 
    RowBox[{"Method", "\[Rule]", "Gradient"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.51723497628954*^9, 3.517234987579115*^9}, {
  3.517235166347505*^9, 3.517235215609198*^9}, {3.517235262829498*^9, 
  3.517235264501837*^9}, {3.517235384884885*^9, 3.517235386338393*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CapitalDelta]H", "\[Rule]", "74222.7868973488`"}], ",", 
   RowBox[{"\[CapitalDelta]S", "\[Rule]", 
    RowBox[{"-", "18.226766932305235`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.517235202177897*^9, 3.517235205533419*^9}, 
   3.517235265693463*^9, 3.517235387357095*^9, 3.517235851973358*^9, 
   3.517238208219232*^9, {3.517239298661239*^9, 3.517239320410365*^9}, 
   3.51724754217844*^9, 3.517248560129263*^9, {3.517249398123481*^9, 
   3.517249426652922*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp1WeightedLogPlot", "=", 
  RowBox[{"LogPlot", "[", 
   RowBox[{
    RowBox[{"model", "/.", "exp1WeightedParams"}], ",", 
    RowBox[{"{", 
     RowBox[{"T", ",", "200", ",", "300"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517235284803351*^9, 3.517235310760252*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVyndQ0wccBfBAEuOAghAZESRhj1gJUhc5+AIqS0IlnigiOLCSEDJ+nog1
OACDuDUsERIIWAwqskRRwS+oxcp0oSBWSqumVsTayCFCbfrHu3efe4+1RRK9
zZhEIkUa8n9rK0MoJJIAGD4jS1vvcDD0c1LwF4Nf1SRcHGvjoC78cMaYkQCW
+yQHsVs56Pq+kzRCFsDKw9z+gmYOVvhGT/XTBDDxgF8rbeSgqjVurN5MAPWf
a2ge5zl4+rlMt93B8Fd4eDcc4eCPZsWdPf4CcInmHV7I56C4JoypyxCAYn+n
NGfAG3ezjf3T2wTQ6NU7ai3yxk+al+aPSEJYxz534KmRNyqjrSSy5UIQPEvr
P81agGEvYgqOZgqhfma11+nob5FV9jH8Q7sQXNayKtNT56Mwoa6ePisZ2lrv
vi3SsLFjXP76SlgyFJcGVecPeSGvo7RCfSwZnJPddppaeOGfaT3saV3JQPcP
j2hd44l6ppNw/iwRePMmVmxVeaCjca9PCU8EL8tjDpIH3XF7S/bdnGMi+EWu
jn3q4Y499YW/tzwQwZnv83m2IjesLO9ubKCnwN+++bs9r7higdhsjRs/BS5d
uk/dZeqKWkIrH8437Nd2p2hjXfDRap6E0ZcCzJ/7ThQ2OqODcNVIEUMM7fKp
hAc0ZxyUS5iDG8UgCDgyOT/BCWuFJfZFxWK4vOfecfEdRzx/yvmn0iEx2FED
1yU6OOJVZeO4E1MCgTb71vdks3DxyRRSUrwEPDtrlu7/xMT+u+lKfZkE5Hlf
94atZ6Kyr/DD1JAEbJdxclVKB1xyUvGu0kIKGe2bd2VsnofxPnw/jq8UTt0o
mf5oqT2aB7mMpvGlsEDVMBjgaYf89+W6xJ1SWDRslOM3fS46TncPMcuTgntf
vXnZlC16qv1JjAYpaKL295pO2uDth0Zf7z2RQjOry6VOZ426Hfe3LPokhSqn
OGHuX1aoqg0wCbWWwceQRDvuizk4FHedYbNYBqn/5pll/kHH2IPtmaFrZRBl
e8DJUm+J28IP+NinySBCyyUZ/2OBk3JYWVMgA+V48A9Z0yzQedVF9ZsmGZwL
5Ua9njEbswqr+Puey+AVrSwwY445SqOrRU8mZLBCGPR2m+AbHDkf39FjR0CP
C79Lc8gEx0T0E4e4BDivEs+jdM/EJdVxl8o2ELCsTZ3ZzZqBs46unp2QTkBf
xNYQeQwNhU8jBgaKCRgKbqIqa6nYbDMg3l5CwFwi82RwFRXNY5PIeoPzH7/L
1muo2DiYxTZVE6D5knozJpeKxsPNewPKCChO3ejntIuKRe8WOFWcI6BOP/dQ
N5eKHUZ0UUo1AVGbhhip9yg4L1hDmjD4WT/LzbeVgkSWd57iMgG8xw9VH5so
aEOLbFHXEOBRurFXeoGCiSYK84d1BOy0N/MjjlNw0mq8YdFVAjad1brmrKFg
1DpF2G2D9cv3vIqMpKDmDP3XqGsEJAa4mlmupGCoHYcmaCJgBIc1qsUUzGUJ
15+9QUCp6MP96wwKvtkyPuJ2k4CqmdkvMywpuKxCkdFgsCr8YnyECQWHXMsv
dDUTkJ2SXvxiiowLkzgQ20LAaK3VhsoxMiq0tx6/Nlgfa5slGyVj/9tIwY5b
BNjaya25OjKy2YNTXw3u1n43h/YbGf8Dx6k+6Q==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{200, -17.768573398980244`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-15.935774094164366`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.285186528023216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.894320219336205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.614018254182046`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.395329053217216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.215988124561399`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.063971917262773`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.932044374220226`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.330603908176274`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.680016342035124`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.289150033348113`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.008848068193954`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.790158867229126, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.610817938573309, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.458801731274683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.326874188232134, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.725433722188183, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.074846156047033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.683979847360021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.403677882205863, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.184988681241033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.005647752585217, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.853631545286591, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.721704002244043, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-18.420680743952367`, 
       FormBox["\"\"", TraditionalForm]}, {-13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-15.935774094164366`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.285186528023216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.894320219336205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.614018254182046`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.395329053217216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.215988124561399`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.063971917262773`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.932044374220226`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.330603908176274`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.680016342035124`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.289150033348113`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.008848068193954`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.790158867229126, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.610817938573309, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.458801731274683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.326874188232134, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.725433722188183, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.074846156047033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.683979847360021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.403677882205863, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.184988681241033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.005647752585217, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.853631545286591, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.721704002244043, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{200, 300}, {-17.768573398980244`, -2.48487679071443}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{-18.420680743952367`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-15.935774094164366`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-15.285186528023216`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.894320219336205`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.614018254182046`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.395329053217216`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.215988124561399`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.063971917262773`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-13.932044374220226`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.330603908176274`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.680016342035124`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.289150033348113`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.008848068193954`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.790158867229126, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.610817938573309, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.458801731274683, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.326874188232134, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.725433722188183, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.074846156047033, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.683979847360021, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.403677882205863, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.184988681241033, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.005647752585217, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.853631545286591, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.721704002244043, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.517235311188084*^9, 3.517235420546963*^9, 3.517235853836034*^9, 
   3.517238208479155*^9, {3.517239298860037*^9, 3.517239320600013*^9}, 
   3.517247542382133*^9, 3.517248561908934*^9, {3.517249398434095*^9, 
   3.517249426866023*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"exp1WeightedLogPlot", ",", "exp1ListLogPlot"}], "]"}]], "Input",
 CellChangeTimes->{{3.517235422205119*^9, 3.517235430837999*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVyndQ0wccBfBAEuOAghAZESRhj1gJUhc5+AIqS0IlnigiOLCSEDJ+nog1
OACDuDUsERIIWAwqskRRwS+oxcp0oSBWSqumVsTayCFCbfrHu3efe4+1RRK9
zZhEIkUa8n9rK0MoJJIAGD4jS1vvcDD0c1LwF4Nf1SRcHGvjoC78cMaYkQCW
+yQHsVs56Pq+kzRCFsDKw9z+gmYOVvhGT/XTBDDxgF8rbeSgqjVurN5MAPWf
a2ge5zl4+rlMt93B8Fd4eDcc4eCPZsWdPf4CcInmHV7I56C4JoypyxCAYn+n
NGfAG3ezjf3T2wTQ6NU7ai3yxk+al+aPSEJYxz534KmRNyqjrSSy5UIQPEvr
P81agGEvYgqOZgqhfma11+nob5FV9jH8Q7sQXNayKtNT56Mwoa6ePisZ2lrv
vi3SsLFjXP76SlgyFJcGVecPeSGvo7RCfSwZnJPddppaeOGfaT3saV3JQPcP
j2hd44l6ppNw/iwRePMmVmxVeaCjca9PCU8EL8tjDpIH3XF7S/bdnGMi+EWu
jn3q4Y499YW/tzwQwZnv83m2IjesLO9ubKCnwN+++bs9r7higdhsjRs/BS5d
uk/dZeqKWkIrH8437Nd2p2hjXfDRap6E0ZcCzJ/7ThQ2OqODcNVIEUMM7fKp
hAc0ZxyUS5iDG8UgCDgyOT/BCWuFJfZFxWK4vOfecfEdRzx/yvmn0iEx2FED
1yU6OOJVZeO4E1MCgTb71vdks3DxyRRSUrwEPDtrlu7/xMT+u+lKfZkE5Hlf
94atZ6Kyr/DD1JAEbJdxclVKB1xyUvGu0kIKGe2bd2VsnofxPnw/jq8UTt0o
mf5oqT2aB7mMpvGlsEDVMBjgaYf89+W6xJ1SWDRslOM3fS46TncPMcuTgntf
vXnZlC16qv1JjAYpaKL295pO2uDth0Zf7z2RQjOry6VOZ426Hfe3LPokhSqn
OGHuX1aoqg0wCbWWwceQRDvuizk4FHedYbNYBqn/5pll/kHH2IPtmaFrZRBl
e8DJUm+J28IP+NinySBCyyUZ/2OBk3JYWVMgA+V48A9Z0yzQedVF9ZsmGZwL
5Ua9njEbswqr+Puey+AVrSwwY445SqOrRU8mZLBCGPR2m+AbHDkf39FjR0CP
C79Lc8gEx0T0E4e4BDivEs+jdM/EJdVxl8o2ELCsTZ3ZzZqBs46unp2QTkBf
xNYQeQwNhU8jBgaKCRgKbqIqa6nYbDMg3l5CwFwi82RwFRXNY5PIeoPzH7/L
1muo2DiYxTZVE6D5knozJpeKxsPNewPKCChO3ejntIuKRe8WOFWcI6BOP/dQ
N5eKHUZ0UUo1AVGbhhip9yg4L1hDmjD4WT/LzbeVgkSWd57iMgG8xw9VH5so
aEOLbFHXEOBRurFXeoGCiSYK84d1BOy0N/MjjlNw0mq8YdFVAjad1brmrKFg
1DpF2G2D9cv3vIqMpKDmDP3XqGsEJAa4mlmupGCoHYcmaCJgBIc1qsUUzGUJ
15+9QUCp6MP96wwKvtkyPuJ2k4CqmdkvMywpuKxCkdFgsCr8YnyECQWHXMsv
dDUTkJ2SXvxiiowLkzgQ20LAaK3VhsoxMiq0tx6/Nlgfa5slGyVj/9tIwY5b
BNjaya25OjKy2YNTXw3u1n43h/YbGf8Dx6k+6Q==
      "]]}}, 
   GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQGZDj/3HfNIWGd4AMx1yHJ4pJ3ztTZXH8JvyHaY
5JCgfUpYG8I/kOOwUq3sk916dQifIc9h/8Ps6p/xKlD9+Q5JfR92PPBRhPIL
HHZEGxvY5MhA+A8KHIRPtRQYSotDzS90WBK1puf4OiEIX6HI4Y4m9zGDN9xQ
+4ocTOvTCjafYDkw1NwLAPoNcGI=
    "], {
     {Hue[0.67, 0.6, 0.6], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 12], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 13], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 14], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 15], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 16], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 17], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 18], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 19], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 20], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 21], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 22]}, {}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{200, -17.768573398980244`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-15.935774094164366`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.285186528023216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.894320219336205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.614018254182046`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.395329053217216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.215988124561399`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.063971917262773`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.932044374220226`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.330603908176274`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.680016342035124`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.289150033348113`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.008848068193954`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.790158867229126, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.610817938573309, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.458801731274683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.326874188232134, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.725433722188183, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.074846156047033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.683979847360021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.403677882205863, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.184988681241033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.005647752585217, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.853631545286591, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.721704002244043, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-18.420680743952367`, 
       FormBox["\"\"", TraditionalForm]}, {-13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-15.935774094164366`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.285186528023216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.894320219336205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.614018254182046`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.395329053217216`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.215988124561399`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.063971917262773`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.932044374220226`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.330603908176274`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.680016342035124`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.289150033348113`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.008848068193954`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.790158867229126, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.610817938573309, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.458801731274683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.326874188232134, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.725433722188183, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.074846156047033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.683979847360021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.403677882205863, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.184988681241033, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.005647752585217, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.853631545286591, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.721704002244043, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{200, 300}, {-17.768573398980244`, -2.48487679071443}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{-18.420680743952367`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-15.935774094164366`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-15.285186528023216`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.894320219336205`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.614018254182046`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.395329053217216`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.215988124561399`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.063971917262773`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-13.932044374220226`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.330603908176274`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.680016342035124`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.289150033348113`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.008848068193954`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.790158867229126, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.610817938573309, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.458801731274683, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.326874188232134, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.725433722188183, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.074846156047033, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.683979847360021, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.403677882205863, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.184988681241033, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.005647752585217, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.853631545286591, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.721704002244043, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.517235431289406*^9, 3.517235857028157*^9, 3.517238208705103*^9, {
   3.51723929936799*^9, 3.51723932079666*^9}, 3.517247542663945*^9, {
   3.517249398558754*^9, 3.51724942698993*^9}}]
}, Open  ]],

Cell["\<\
Much better. The fit looks great and the parameters we got are very close to \
the expected values. Let's take a look at the percent error again.\
\>", "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517239589535204*^9, 3.517239630823014*^9}},
 FormatType->"TextForm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp1WeightedResiduals", "=", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"model", "/.", "exp1WeightedParams"}], ",", 
     RowBox[{"{", 
      RowBox[{"T", ",", "200", ",", "300", ",", "10"}], "}"}]}], "]"}], "-", 
   "exp1k"}]}]], "Input",
 CellChangeTimes->{{3.517235437316088*^9, 3.517235465241219*^9}, {
  3.517235908516484*^9, 3.517235914169822*^9}, {3.517248493618753*^9, 
  3.517248522431634*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.7535732047633725`*^-9"}], ",", "1.9021758012070397`*^-8", 
   ",", 
   RowBox[{"-", "9.76425705663082`*^-8"}], ",", "2.5909215666437676`*^-7", 
   ",", "1.548411932865693`*^-6", ",", "5.632541691278004`*^-6", ",", 
   RowBox[{"-", "0.00007821893827781993`"}], ",", 
   RowBox[{"-", "0.0003503522795892068`"}], ",", 
   RowBox[{"-", "0.00008064771474094491`"}], ",", 
   RowBox[{"-", "0.0016183131361528838`"}], ",", "0.008913453624631626`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.517235466275597*^9, 3.51723587285392*^9, 3.517235914529269*^9, 
   3.517238208998538*^9, {3.517239299621297*^9, 3.517239321199998*^9}, 
   3.517247542703955*^9, {3.517248495571976*^9, 3.517248523261988*^9}, 
   3.517248565408853*^9, {3.517249398608518*^9, 3.51724942705087*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"exp1WeightedResiduals", "/", 
    RowBox[{"exp1", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "Medium"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.517235470231887*^9, 3.517235579252777*^9}, {
  3.517235622810695*^9, 3.517235629589701*^9}, {3.517235884985891*^9, 
  3.51723589652239*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7Jt7Cxi35m7dDxVwMArY313ocMAewuVwUHl4
7W3v501QeQEHjr6UKwsKFkHlRRwyxRR+/OdfCuVLOChY3VR1rlgA5cs4tLzX
LbDJ2AHVr+DwNDV6os6HPVC+ksOD9BXW3YsaoXwVhxv1yuvW66yG8tUcBF4v
U1Bduc9+qLkXAOTxZRY=
   "], {
    {Hue[0.67, 0.6, 0.6], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 12], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 13], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 14], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 15], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 16], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 17], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 18], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 19], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 20], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 21], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 22]}, {}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.517235475348362*^9, 3.517235580522276*^9}, {
   3.517235626040273*^9, 3.517235629882701*^9}, {3.517235876241863*^9, 
   3.51723591578399*^9}, 3.517238209453309*^9, {3.517239299794706*^9, 
   3.517239321427977*^9}, 3.517247542838751*^9, {3.517248501539957*^9, 
   3.517248525729949*^9}, 3.51724856702611*^9, {3.517249398748216*^9, 
   3.517249427220144*^9}}]
}, Open  ]],

Cell[TextData[{
 "Roughly randomly distributed, and almost all of them are within 20 %. As we \
have seen, choosing the correct curve-fitting strategy, based on the type of \
experiment that was run, is very important. Even good data will yield poor \
results if it' s not analyzed correctly.\n\nAs an historical aside, note that \
the amount of computation required to do this non-linear fitting was \
completely out of reach before the 1960s or so. Luckily for everyone \
involved, most commonly used equations in chemistry can be linearized. For \
instance, let's take the log of both sides of the Eyring equation:\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"log", " ", "k"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"log", " ", "[", 
      FractionBox[
       SubscriptBox["k", "b"], "h"], "]"}], " ", "+", " ", 
     RowBox[{"log", "[", "T", "]"}], " ", "-", 
     FractionBox[
      RowBox[{"\[CapitalDelta]H", "-", "T\[CapitalDelta]S"}], 
      RowBox[{"R", " ", "T"}]], " "}]}], TraditionalForm]]],
 ",\nwhich implies that\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"log", "[", 
     FractionBox["k", "T"], "]"}], " ", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["\[CapitalDelta]H", "R"]}], 
      FractionBox["1", "T"]}], "-", 
     FractionBox["\[CapitalDelta]S", "R"], "+", 
     RowBox[{"log", "[", 
      FractionBox[
       SubscriptBox["k", "b"], "h"], "]"}], " "}]}], TraditionalForm]]],
 ",\nwhich is wonderful. We can calculate the stuff on the left (as we have \
both ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["T", TraditionalForm]]],
 ") and then we can plot it versus ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "T"], TraditionalForm]]],
 ", leading to a simple ",
 StyleBox["linear",
  FontSlant->"Italic"],
 " curve-fitting problem."
}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517239640558361*^9, 3.517239764472445*^9}, {
  3.51724670861797*^9, 3.517246922268445*^9}, {3.517246967229251*^9, 
  3.517247064473551*^9}, {3.517247099900021*^9, 3.517247341485257*^9}, {
  3.517247708942627*^9, 3.517247715212386*^9}},
 FormatType->"TextForm"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"exp1Linear", " ", "=", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "/", "exp1T"}], ",", 
      RowBox[{"Log", "[", 
       RowBox[{"exp1k", "/", "exp1T"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "exp1Linear", "]"}]}], "Input",
 CellChangeTimes->{{3.517247351389958*^9, 3.517247357669317*^9}, {
  3.517247627562156*^9, 3.517247650818315*^9}, {3.517247681001336*^9, 
  3.517247737806286*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", "200"], 
      RowBox[{"-", "22.979474048106617`"}]},
     {
      FractionBox["1", "210"], 
      RowBox[{"-", "21.06095914419567`"}]},
     {
      FractionBox["1", "220"], 
      RowBox[{"-", "18.93227935175277`"}]},
     {
      FractionBox["1", "230"], 
      RowBox[{"-", "17.28035643230074`"}]},
     {
      FractionBox["1", "240"], 
      RowBox[{"-", "15.668089195825024`"}]},
     {
      FractionBox["1", "250"], 
      RowBox[{"-", "14.17161291386899`"}]},
     {
      FractionBox["1", "260"], 
      RowBox[{"-", "12.666379981096648`"}]},
     {
      FractionBox["1", "270"], 
      RowBox[{"-", "11.374977743323802`"}]},
     {
      FractionBox["1", "280"], 
      RowBox[{"-", "10.305472699120003`"}]},
     {
      FractionBox["1", "290"], 
      RowBox[{"-", "9.160208326254754`"}]},
     {
      FractionBox["1", "300"], 
      RowBox[{"-", "8.301780977509553`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.517247738116891*^9, {3.51724939884029*^9, 3.517249427449875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"exp1Linear", ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "Medium"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.517247750505383*^9, 3.517247759192549*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQXS2yzv1hVYk937PV5/f9MjsgYtEobNFYbJ+1bRfL
bH7TA/OEnmg6ziuyX9LMd2flO6MDso2L1rKdL7Qv/ZJdcNTd8IAgGBTaOx+q
Pckfpn/gz8qPl3yTCuy/uN1cejdc54DCj0b5H4359lc5Dx/UD9U8UPKU8aRV
eJ598WwD0b/71Q7IXnEEolx7BdGXr9LmqBz48OMwY799jr3L/OTLbEFKB/yl
X2xp9Mu23/nKk7N5lsKBoeZeAHekpGA=
   "], {
    {Hue[0.67, 0.6, 0.6], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 12], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 13], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 14], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 15], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 16], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 17], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 18], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 19], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 20], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 21], InsetBox[
      StyleBox["\<\"\[FilledCircle]\"\>",
       StripOnInput->False,
       FontSize->Medium], 22]}, {}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.0035, -22.},
  PlotRange->{{0.0033333333333333335`, 
   0.005}, {-22.979474048106617`, -8.301780977509553}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.517247759362494*^9, {3.517249399199944*^9, 3.517249427759473*^9}}]
}, Open  ]],

Cell[TextData[{
 "Now that we' ve linearized the data, we can do a much easier ",
 StyleBox["linear",
  FontSlant->"Italic"],
 " curve-fit using Mathematica's linear fitting routine, Fit. We're looking \
for the constant coefficient (which will be ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["\[CapitalDelta]S", "R"], "+", 
    RowBox[{"log", "[", 
     FractionBox[
      SubscriptBox["k", "b"], "h"], "]"}]}], TraditionalForm]]],
 ") and the linear coefficient (which will be ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    FractionBox["\[CapitalDelta]H", "R"]}], TraditionalForm]]],
 ")."
}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517247763643847*^9, 3.517247821818795*^9}, {
   3.517247859282626*^9, 3.51724794573727*^9}, 3.517248709257691*^9},
 FormatType->"TextForm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp1LinearFit", "=", 
  RowBox[{"Fit", "[", 
   RowBox[{"exp1Linear", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517247825232695*^9, 3.517247854381479*^9}, {
  3.517247959068005*^9, 3.517247982322683*^9}}],

Cell[BoxData[
 RowBox[{"21.573768879846014`", "\[InvisibleSpace]", "-", 
  RowBox[{"8925.998958039281`", " ", "x"}]}]], "Output",
 CellChangeTimes->{
  3.517247854720151*^9, {3.517247967200112*^9, 3.51724798260072*^9}, {
   3.517249399456521*^9, 3.51724942782782*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"constCoeff", ",", " ", "linearCoeff"}], "}"}], " ", "=", " ", 
  RowBox[{"CoefficientList", "[", 
   RowBox[{"exp1LinearFit", ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.517247986158512*^9, 3.517247996247346*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"21.573768879846014`", ",", 
   RowBox[{"-", "8925.998958039281`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.517247996609191*^9, {3.517249399729698*^9, 3.517249428075168*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalDelta]S", "/", "R"}], "+", 
       RowBox[{"Log", "[", 
        RowBox[{"kb", "/", "h"}], "]"}]}], "\[Equal]", "constCoeff"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[CapitalDelta]H"}], "/", "R"}], "\[Equal]", 
      "linearCoeff"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[CapitalDelta]H", ",", "\[CapitalDelta]S"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.517247999913718*^9, 3.517248051182951*^9}, 
   3.517248704549884*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[CapitalDelta]S", "\[Rule]", 
     RowBox[{"-", "18.17718286433623`"}]}], ",", 
    RowBox[{"\[CapitalDelta]H", "\[Rule]", "74214.96840864679`"}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.517248023885116*^9, 3.517248051522962*^9}, 
   3.517248704987246*^9, {3.517249399894557*^9, 3.517249428272571*^9}}]
}, Open  ]],

Cell["\<\
Interestingly, the linear method gives very good results, with significantly \
less computational effort (this type of linear fit could be done on a \
handheld calculator).\
\>", "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.517248157036431*^9, 3.517248179704553*^9}, {
  3.517249219336272*^9, 3.517249272582192*^9}},
 FormatType->"TextForm"]
},
WindowSize->{1278, 779},
WindowMargins->{{0, Automatic}, {2, Automatic}},
FrontEndVersion->"7.0 for Linux x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1212, 29, 115, "Input",
 Evaluatable->False],
Cell[1760, 51, 167, 3, 32, "Input"],
Cell[1930, 56, 566, 16, 77, "Input"],
Cell[2499, 74, 718, 17, 77, "Input"],
Cell[3220, 93, 594, 17, 69, "Input"],
Cell[3817, 112, 265, 6, 32, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4107, 122, 574, 12, 32, "Input"],
Cell[4684, 136, 11936, 201, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16657, 342, 429, 9, 32, "Input"],
Cell[17089, 353, 11886, 229, 235, "Output"]
}, Open  ]],
Cell[28990, 585, 265, 6, 32, "Input",
 Evaluatable->False],
Cell[29258, 593, 1342, 36, 145, "Input"],
Cell[30603, 631, 289, 7, 32, "Input"],
Cell[CellGroupData[{
Cell[30917, 642, 304, 8, 55, "Input"],
Cell[31224, 652, 1105, 28, 200, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32366, 685, 350, 8, 32, "Input"],
Cell[32719, 695, 11669, 239, 235, "Output"]
}, Open  ]],
Cell[44403, 937, 267, 6, 32, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[44695, 947, 369, 7, 32, "Input"],
Cell[45067, 956, 547, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45651, 972, 336, 8, 32, "Input"],
Cell[45990, 982, 20434, 387, 240, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66461, 1374, 170, 3, 32, "Input"],
Cell[66634, 1379, 21970, 428, 240, "Output"]
}, Open  ]],
Cell[88619, 1810, 715, 13, 104, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[89359, 1827, 694, 15, 32, "Input"],
Cell[90056, 1844, 743, 14, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90836, 1863, 451, 9, 32, "Input"],
Cell[91290, 1874, 2157, 53, 214, "Output"]
}, Open  ]],
Cell[93462, 1930, 1110, 25, 122, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[94597, 1959, 378, 10, 32, "Input"],
Cell[94978, 1971, 2006, 52, 241, "Output"]
}, Open  ]],
Cell[96999, 2026, 965, 20, 104, "Input",
 Evaluatable->False],
Cell[97967, 2048, 303, 6, 32, "Input"],
Cell[98273, 2056, 200, 5, 32, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[98498, 2065, 486, 8, 32, "Input"],
Cell[98987, 2075, 522, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99546, 2090, 303, 7, 32, "Input"],
Cell[99852, 2099, 11844, 229, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111733, 2333, 178, 3, 32, "Input"],
Cell[111914, 2338, 13349, 268, 235, "Output"]
}, Open  ]],
Cell[125278, 2609, 282, 6, 32, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[125585, 2619, 448, 11, 32, "Input"],
Cell[126036, 2632, 825, 16, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126898, 2653, 533, 13, 32, "Input"],
Cell[127434, 2668, 2116, 52, 222, "Output"]
}, Open  ]],
Cell[129565, 2723, 2176, 57, 200, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[131766, 2784, 517, 13, 55, "Input"],
Cell[132286, 2799, 1559, 50, 280, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133882, 2854, 263, 6, 32, "Input"],
Cell[134148, 2862, 1995, 52, 239, "Output"]
}, Open  ]],
Cell[136158, 2917, 802, 23, 59, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[136985, 2944, 300, 7, 32, "Input"],
Cell[137288, 2953, 268, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[137593, 2963, 274, 6, 32, "Input"],
Cell[137870, 2971, 218, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138125, 2981, 596, 18, 32, "Input"],
Cell[138724, 3001, 385, 9, 31, "Output"]
}, Open  ]],
Cell[139124, 3013, 358, 8, 32, "Input",
 Evaluatable->False]
}
]
*)

(* End of internal cache information *)
